#
# spec file for package google-sap-agent
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#

%global provider        github
%global provider_tld    com
%global project         GoogleCloudPlatform
%global repo            sapagent
%global provider_prefix %{provider}.%{provider_tld}/%{project}/%{repo}
%global import_path     %{provider_prefix}

Name:           google-cloud-sap-agent
Version:        2.8
Release:        150100.3.20.1
Summary:        Google Cloud for SAP
License:        Apache-2.0
Group:          System/Daemons
URL:            https://%{provider_prefix}
Source0:        %{repo}-v%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  golang(API) = 1.21
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

BuildRequires:  golang-packaging
BuildRequires:  pkgconfig(systemd)
%{?systemd_requires}
%if 0%{?suse_version} && 0%{?suse_version} == 1220
%define systemd_prefix /lib
%else
%define systemd_prefix /usr/lib
%endif


%{go_nostrip}
%{go_provides}

%description
Google Cloud SAP agent. Agent for GCE instances running SAP workloads.

%prep
%setup -q -n sapagent-v%{version}
%setup -T -D -a 1 -n sapagent-v%{version}

%build
%goprep %{import_path}
pushd cmd/local
go build -mod=vendor -o google_cloud_sap_agent main.go
popd

%install
install -d %{buildroot}%{_bindir}
install -d %{buildroot}%{systemd_prefix}/systemd/system
install -d %{buildroot}%{_datadir}/google-cloud-sap-agent
install -p -m 0755 %{_builddir}/sapagent-v%{version}/cmd/local/google_cloud_sap_agent %{buildroot}%{_bindir}
install -p -m 0622 build/google-cloud-sap-agent.service %{buildroot}%{systemd_prefix}/systemd/system
install -p -Dm 0644 build/configuration.json %{buildroot}%{_sysconfdir}/%{name}/configuration.json

%pre
%service_add_pre google-cloud-sap-agent.service

%preun
%service_del_preun google-cloud-sap-agent.service

%post
%service_add_post google-cloud-sap-agent.service

%postun
%service_del_postun google-cloud-sap-agent.service


%files
%defattr(0644,root,root,0755)
%dir %{_sysconfdir}/%{name}
%config(noreplace) %attr(0644,root,root) %{_sysconfdir}/%{name}/configuration.json
%license LICENSE
%{_datadir}/google-cloud-sap-agent
%attr(0755,root,root) %{_bindir}/*
%{systemd_prefix}/systemd/system/google-cloud-sap-agent.service

%changelog
* Tue Nov 28 2023 adrian.glaubitz@suse.com
- Update to version 2.8 (bsc#1217373, bsc#1217374)
  * Bump agent version to 2.8 to support C3/M3 certification
  * Update go.yml to use go 1.21
  * Switch from "slices" to "go_exp.../slices" for go version dependency
  * Use newly refactored discovery packages.
  * Fixes issue with diskname from source or device name
  * Adds extreme disk type IOps and Throughput for host metrics
  * Add `INTEGRATION` target config environment for collection definition testing
  * Add project number to SAP System proto
  * Add a cache to discovered resources. This reduces the number of API
    calls needed to perform System Discovery
  * Replace windows wmic hardware queries with PowerShell wmi queries
  * Fix test flakiness
  * Improve development process for collection definition configuration
  * HANA PD based snapshot and restore - changes to add wait for uploading
  * Fix for kokoro build issue in processmetrics/networkstats
  * GCBDR SAPCoreAPP Package in Agent for SAP
  * Add version tracking for WLM validation config
  * Send workload validation config to remote instances for use during remote collection
  * Add flag for passing in workload validation config into remote collection OTE
  * Bump google.golang.org/grpc from 1.58.2 to 1.58.3
- from version 2.7
  * Added ote for hma dashboards migration
  * Increase Max backoff in storage package to 300 seconds
  * Added subpaths for collection of required TCP metrics
  * Add more debug logs and increase the wait-time for PD operations in restore
  * No public description
  * Add 30 second timeout to read/write from the local file system for Backint
  * No public description
  * Adds RHEL 9 VM Manager policy
  * Extract cloud-related discovery functions into separate file
  * Adding timeout to systemReplication.py command execution
  * Allow download attempts without verifying connection to bucket
  * Invoke `collectiondefinition.Start` when starting the agent in daemon mode
  * SAP Agent CLI - usability improvements for flags and help menu
  * Add host project information to HANA DB component discovery data.
  * Use proto names for default configuration during Backint installation
  * Extending logging capabilities to all packages of the agent
  * Added a feature for exposing TCP connection metrics
  * Migrating context logging logic to all packages of SAP Agent
  * Add an ifthisthenthatlint to ensure new script is kept in sync with rule proto
  * (collectiondefition) - Discard unknown fields and remove breaking metrics
  * Moving commandlineexecutor from internal to shared for sqlserveragent
  * Define startup function for collectiondefinition package
  * Check error on close of destFile in backint restore
  * Allow trailing zeros for millisecond timestamps in Backint
  * Add pid to all agent logs
  * Bump SAP Agent version to 2.7 (placeholder release version)
  * Separate collection definition validation functionality into a separate file
  * Add datetime to migration folder for Backint installation
  * Add symlink for Backint log file to install directory
  * Set a deadline for the final flush to cloud logging
  * Increase chunk retry deadline in storage package
  * Fix order dependent tests in sapagent/internal/storage
  * Change support bundle feature to collect the OTE logs from new path
  * Usage logging for remote WLM validation metrics collection from the collector instance
  * Extract discovery functions performed on the host to a separate file
  * Improve agent shutdown experience in daemon mode
  * Fix Backint restoring incorrect file
  * Google Events - rule proto initial submission
  * Move gce package to shared folder for use by SQL Server agent
  * Add GCS integration into collectiondefinition package
  * Standardize import aliases
  * go mod updates
  * Fixing go/gotsan data race error in processmetrics_test
  * Add Backint support for Inquire line: `#EBID <external_backup_id>`
  * Chown Backint install directories to user/group of the opt/ folder
  * Create OTE logs under a subdir under /var/log as /var/log is only writable by root
  * Will not create an empty log file for logusage logs and one
    time execution logs will have 0666 file mode
  * Setting the log file created to world read+write permission
  * Bump golang.org/x/net from 0.15.0 to 0.17.0
  * Add recovery_bucket parameter to Backint
  * Extract SAP related discovery functions to a separate file
  * Fix Backint install directory
  * Fix Backint parallel uploads
  * Move maintenance collector to beta API
  * Pruning batches to prevent time series duplication
  * Added a logger for incorporating service context keys in logs
  * Encode the DB password string to handle passwords with special characters
  * Handling non error scenarios better in netweaver.go
  * Internal change
  * fixes typo on backint install
  * Allow all users to execute google_cloud_sap_agent
  * Fix hdbbackint script.
  * Subdirs for Backint DIAGNOSE temporary files
  * Report zero-value metrics for upcoming maintenance
  * Clean up gcealpha functionality
  * Fix default configuration values in daemon and backint
  * Update the comment in proto to reflect that the metric
    path in skip list should start with /sap
  * Implemented separation of context of different services
* Fri Oct 20 2023 adrian.glaubitz@suse.com
- Update to version 2.6 (bsc#1215672, bsc#1215673)
  * Rolling back previous change for storing Project Number,
    Project ID is sufficient, no need to add complexity
  * Determine location of HANA global.ini using SAP system discovery logic
  * Add numeric project ID prefix to object name for ReadMetrics
  * Discovery now looks up and stores project number with discovery data
  * ReadMetrics updates for IAM permissions and bucket object names
  * fixing the bug in backoff logic, using separate policies
    for each collector and adding some logs
  * Backint migration from the old agent and supporting legacy parameters
  * adding new backoff policies for process metrics and fixing the
    bug in process metrics sapservice collector
  * Bump SAP Agent version to 2.6
  * Fix an issue where HANA hosts may not be discovered
    properly if hostname differs from instance name
  * Use Go 1.20 friendly sorting solution
  * adding retries in process metrics logic with backoffs
  * Fix parsing of instance (host/VM) name in Pacemaker pcmk_delay_max metric
  * Add the collection definition changes for the SAP HANA Topology metrics
  * Template for Cloud Monitoring Alerts for Backint errors
  * adding backoff to InstanceProperties to each collector
  * Reduced the number of parameters of startXX functions
    by consolidating them into respective structs
  * completing TODO (b/298315981): Create a map from skipped
    list metrics and pass it to collectors.
  * Proto package name changes to reflect the current path
  * Use instance_name instead of instance_id for baremetal systems
  * Decode encryption keys for Backint.
  * Moving hareplication metric to fast moving metrics
  * Added backoffs package in process metrics to keep the backoff policies
    and retry policies separately and make it reusable acrosss process metrics
  * Install Backint OTE
  * Adding skip list logic to process metrics
  * Separating fastmoving metrics into a separate file from other process metrics
  * Update remote collection to use collected instance's Cloud Properties
  * ReadMetrics upload to bucket and send status to monitoring
  * Remove local implementation of DW API in favor of using generated third_party version
  * ReadMetrics read input file and write results to local filesystem
  * Clean up command line executions to collect SAP Control metrics
  * Adding new OTE structure for ReadMetrics
  * Add the SUSE specific spec file to keep upstream changes and SUSE packaging in sync
  * Collect and report upcoming maintenance
  * Add basepath override and gcealpha functionality
  * Making proto changes for process metrics re-arch
  * Changes for generating HANA Insights locally into a markdown file
  * Delay feature specific daily action logs by 24 hours
    to avoid noise created by startup failures
  * Update to the rule "maximum_invalid_connect_attempts"
  * Add some missing related resources
  * Fix rate limiting for compression enabled uploads/downloads
  * Optional User-Agent parameter added to storage package client connection
  * Relocate gcealpha to /internal
  * Fix parse_test error
  * Retries added for opening files in Backint
  * Make processmetrics unit tests hermetic
  * Remove if-this-then-that requirement from WLM validation rule
  * Fix WriteInsight JSON encoding, and add missing elements
  * Add configuration value to change API endpoint for Data Warehouse calls
  * Storage package progress messages based off of read/writes directly to the bucket
  * Make Collect DB Metrics as NO-OP when metrics are being read from override file
  * Remove unused field from backint proto
  * Custom retries for the storage package with exponential backoff and MaxRetries setting
* Thu Aug 31 2023 adrian.glaubitz@suse.com
- Update to version 2.5
  + No upstream changelog provided
* Thu Aug 17 2023 adrian.glaubitz@suse.com
- Install missing default configuration file (bsc#1214293)
* Wed Jul 19 2023 adrian.glaubitz@suse.com
- Update to version 2.1 (bsc#1213397)
  + No upstream changelog provided
* Wed Jul 12 2023 adrian.glaubitz@suse.com
- Update to version 2.0 (bsc#1211516, bsc#1211517)
  + No upstream changelog provided
* Mon May  8 2023 adrian.glaubitz@suse.com
- Update to version 1.5.1 (bsc#1210464, bsc#1210465)
  + No upstream changelog provided
- Raise golang API version to 1.20
* Thu Feb 16 2023 rjschwei@suse.com
- Initial build (#jsc-PED-2879)
  + Version 1.0
